from setuptools import setup

setup(name='OMS_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['OMS_distributions'],
      author='Ori Slasky', 
      author_email='Orislasky@gmail.com',
      zip_safe=False)
